@@ -1,13 +1,5 @@
 """pytest file built from doc/example1.md"""
-from itertools import zip_longest
-
-
-def line_by_line_compare_exact(a, b):
-    """Line by line helper compare function with assertion for pytest."""
-    a_lines = a.splitlines()
-    b_lines = b.splitlines()
-    for a_line, b_line in zip_longest(a_lines, b_lines):
-        assert a_line == b_line
+from phmdoctest.functions import _phm_compare_exact
 
 
 def session_00001_line_6():
@@ -28,10 +20,10 @@ def test_code_14_output_27(capsys):
     for floater in Floats:
         print(floater)
 
-    expected_str = """\
+    _phm_expected_str = """\
 Floats.APPLES
 Floats.CIDER
 Floats.CHERRIES
 Floats.ADUCK
 """
-    line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
+    _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
