@@ -1,26 +1,18 @@
 """pytest file built from doc/example2.md"""
-from itertools import zip_longest
-
-
-def line_by_line_compare_exact(a, b):
-    """Line by line helper compare function with assertion for pytest."""
-    a_lines = a.splitlines()
-    b_lines = b.splitlines()
-    for a_line, b_line in zip_longest(a_lines, b_lines):
-        assert a_line == b_line
+from phmdoctest.functions import _phm_compare_exact
 
 
 def test_code_9_output_14(capsys):
     squares = [1, 4, 9, 16, 25]
     print(squares)
 
-    expected_str = """\
+    _phm_expected_str = """\
 [1, 4, 9, 16, 25]
 """
-    line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
+    _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
 
 
-def test_code_37(capsys):
+def test_code_37():
     a, b = 0, 1
     while a < 1000:
         print(a, end=',')
@@ -34,12 +26,12 @@ def test_code_44_output_51(capsys):
     for w in words:
         print(w, len(w))
 
-    expected_str = """\
+    _phm_expected_str = """\
 cat 3
 window 6
 defenestrate 12
 """
-    line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
+    _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
 
 
 def session_00001_line_75():
@@ -58,7 +50,7 @@ def test_code_87_output_93(capsys):
     d = date.fromordinal(730920)    # 730920th day after 1. 1. 0001
     print(d)
 
-    expected_str = """\
+    _phm_expected_str = """\
 2002-03-11
 """
-    line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
+    _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
